@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-import anydbm, errno, md5, os, stat, struct, sys
+import bsddb, errno, md5, os, stat, struct, sys
 
 from cPickle import dumps, loads
 
@@ -19,7 +19,7 @@ def md5it(f, MAXSIZE, VERBOSITY=0, PROFILES=False):
         h.update(d)
         d = f.read(READSIZE)
         bytesread += len(d)
-        if bytesread > MAXSIZE:
+        if (MAXSIZE != -1) and (bytesread > MAXSIZE):
             if VERBOSITY:
                 hashval = h.hexdigest()
                 print "Stopping processing of %s because we've already hashed max-size (%d) bytes of it.  (The result will be %s.)" % (f, MAXSIZE, hashval)
@@ -42,14 +42,11 @@ def dffem(VERBOSITY, IGNOREDIRS, HARDLINKEM, DELETEEM, MINSIZE, MAXSIZE, PROFILE
 
     tempd = fileutil.NamedTemporaryDirectory()
     db1fname = os.path.join(tempd.name, TMPDB1FNAME)
-    d1 = anydbm.open(db1fname, "n")
-    if VERBOSITY:
-        import whichdb
-        print "database type chosen by anydbm was ", whichdb.whichdb(db1fname)
+    d1 = bsddb.btopen(db1fname, "n")
     tempd.register_file(d1)
     fileutil.remove_if_possible(db1fname)
     db2fname = os.path.join(tempd.name, TMPDB2FNAME)
-    d2 = anydbm.open(db2fname, "n")
+    d2 = bsddb.btopen(db2fname, "n")
     tempd.register_file(d2)
     fileutil.remove_if_possible(db2fname)
     try:
